@@ -183,13 +183,18 @@ def export(
     from pdm.models.candidates import Candidate
 
     lines = ["# This file is @generated by PDM.\n# Please do not edit it manually.\n\n"]
+    collected_req: set[str] = set()
     for candidate in sorted(candidates, key=lambda x: x.identify()):  # type: ignore[attr-defined]
         if isinstance(candidate, Candidate):
             req = dataclasses.replace(candidate.req, specifier=get_specifier(f"=={candidate.version}"), marker=None)
         else:
             assert isinstance(candidate, Requirement)
             req = candidate
+        line = project.backend.expand_line(req.as_line(), options.expandvars)
+        if line in collected_req:
+            continue
         lines.append(project.backend.expand_line(req.as_line(), options.expandvars))
+        collected_req.add(line)
         if options.hashes and getattr(candidate, "hashes", None):
             for item in sorted({row["hash"] for row in candidate.hashes}):  # type: ignore[attr-defined]
                 lines.append(f" \\\n    --hash={item}")
@@ -199,7 +204,13 @@ def export(
         url = source["url"]
         if options.expandvars:
             url = expand_env_vars_in_auth(url)
-        prefix = "--index-url" if source["name"] == "pypi" else "--extra-index-url"
+        source_type = source.get("type", "index")
+        if source_type == "index":
+            prefix = "--index-url" if source["name"] == "pypi" else "--extra-index-url"
+        elif source_type == "find_links":
+            prefix = "--find-links"
+        else:
+            raise ValueError(f"Unknown source type: {source_type}")
         lines.append(f"{prefix} {url}\n")
         if not source.get("verify_ssl", True):
             host = urllib.parse.urlparse(url).hostname
