@@ -81,10 +81,11 @@ class Project:
             global_config = platformdirs.user_config_path("pdm") / "config.toml"
         self.global_config = Config(Path(global_config), is_global=True)
         global_project = Path(self.global_config["global_project.path"])
+        is_conda_base = os.getenv("CONDA_DEFAULT_ENV", "") == "base"
 
         if root_path is None:
             root_path = find_project_root() if not is_global else global_project
-        if not is_global and root_path is None and self.global_config["global_project.fallback"]:
+        if not is_global and root_path is None and self.global_config["global_project.fallback"] and not is_conda_base:
             root_path = global_project
             is_global = True
             if self.global_config["global_project.fallback_verbose"]:
@@ -143,12 +144,18 @@ class Project:
     @property
     def python(self) -> PythonInfo:
         if not self._python:
-            self._python = self.resolve_interpreter()
-            if self._python.major < 3:
+            python = self.resolve_interpreter()
+            if python.major < 3:
                 raise PdmUsageError(
                     "Python 2.7 has reached EOL and PDM no longer supports it. "
                     "Please upgrade your Python to 3.6 or later.",
                 )
+            is_conda_base = os.getenv("CONDA_DEFAULT_ENV", "") == "base"
+            if (
+                self.is_global and is_conda_base and python.path == Path(os.environ["CONDA_PYTHON_EXE"])
+            ):  # pragma: no cover
+                raise PdmUsageError("Can't use global project in conda base environment since it is managed by conda")
+            self._python = python
         return self._python
 
     @python.setter
@@ -208,7 +215,9 @@ class Project:
         if config.get("python.use_venv") and not self.is_global and not os.getenv("PDM_IGNORE_ACTIVE_VENV"):
             # Resolve virtual environments from env-vars
             venv_in_env = os.getenv("VIRTUAL_ENV", os.getenv("CONDA_PREFIX"))
-            if venv_in_env:
+            conda_base = os.getenv("CONDA_DEFAULT_ENV", "") == "base"
+            # We don't auto reuse conda's base env since it may cause breakage when removing packages.
+            if venv_in_env and not conda_base:
                 python = PythonInfo.from_path(get_venv_python(Path(venv_in_env)))
                 if match_version(python):
                     note(
