@@ -25,6 +25,7 @@ import json
 import os
 import shutil
 import sys
+import warnings
 from dataclasses import dataclass
 from io import BufferedReader, BytesIO, StringIO
 from pathlib import Path
@@ -154,9 +155,7 @@ class TestRepository(BaseRepository):
 
     def __init__(self, sources: list[RepositoryConfig], environment: BaseEnvironment, pypi_json: Path):
         super().__init__(sources, environment)
-        self._pypi_data: dict[str, Any] = {}
-        self._pypi_json = pypi_json
-        self.load_fixtures()
+        self._pypi_data = self.load_fixtures(pypi_json)
 
     def get_raw_dependencies(self, candidate: Candidate) -> list[str]:
         try:
@@ -194,11 +193,11 @@ class TestRepository(BaseRepository):
     def get_hashes(self, candidate: Candidate) -> list[FileHash]:
         return []
 
-    def _find_candidates(self, requirement: Requirement) -> Iterable[Candidate]:
+    def _find_candidates(self, requirement: Requirement, minimal_version: bool) -> Iterable[Candidate]:
         for version, candidate in sorted(
             self._pypi_data.get(cast(str, requirement.key), {}).items(),
             key=lambda item: parse_version(item[0]),
-            reverse=True,
+            reverse=not minimal_version,
         ):
             c = Candidate(
                 requirement,
@@ -209,8 +208,9 @@ class TestRepository(BaseRepository):
             c.link = cast(Link, _FakeLink())
             yield c
 
-    def load_fixtures(self) -> None:
-        self._pypi_data = json.loads(self._pypi_json.read_text())
+    @staticmethod
+    def load_fixtures(pypi_json: Path) -> dict[str, Any]:
+        return json.loads(pypi_json.read_text())
 
 
 class Metadata(dict):
@@ -367,7 +367,8 @@ def core() -> Iterator[Core]:
     # Turn off use_venv by default, for testing
     Config._config_map["python.use_venv"].default = False
     main = Core()
-    yield main
+    with warnings.catch_warnings():
+        yield main
     # Restore the config items
     Config._config_map = old_config_map
 
